Exception: WaveInfo::FileFormatError
- Inherits:
-
Exception
- Object
- Exception
- WaveInfo::FileFormatError
- Defined in:
- lib/waveinfo.rb
Overview
Exception raised if there is a problem parsing the Wave file
Exception raised if there is a problem parsing the Wave file